Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1714)

Unified Diff: ash/wm/workspace/workspace_layout_manager.cc

Issue 2871243003: Enable new-virtual-keyboard-behavior flag by default. (Closed)
Patch Set: keep sorted the declarations Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/workspace/workspace_layout_manager.cc
diff --git a/ash/wm/workspace/workspace_layout_manager.cc b/ash/wm/workspace/workspace_layout_manager.cc
index 8ec5067b4757275fa1dff92d4936f31f31979088..aaad8e0d6d99dc1c741d30046089281928fbf92f 100644
--- a/ash/wm/workspace/workspace_layout_manager.cc
+++ b/ash/wm/workspace/workspace_layout_manager.cc
@@ -138,12 +138,13 @@ void WorkspaceLayoutManager::SetChildBounds(aura::Window* child,
void WorkspaceLayoutManager::OnKeyboardBoundsChanging(
const gfx::Rect& new_bounds) {
// If new window behavior flag enabled and in non-sticky mode, do not change
// the work area.
- bool change_work_area =
- (!base::CommandLine::ForCurrentProcess()->HasSwitch(
- ::switches::kUseNewVirtualKeyboardBehavior) ||
- keyboard::KeyboardController::GetInstance()->keyboard_locked());
+ const bool change_work_area =
+ (base::CommandLine::ForCurrentProcess()->HasSwitch(
+ ::switches::kDisableNewVirtualKeyboardBehavior) ||
+ (keyboard::KeyboardController::GetInstance() &&
+ keyboard::KeyboardController::GetInstance()->keyboard_locked()));
if (!change_work_area)
return;
« no previous file with comments | « ash/shelf/shelf_layout_manager_unittest.cc ('k') | ash/wm/workspace/workspace_layout_manager_keyboard_unittest.cc » ('j') | no next file with comments »
@@ -138,12 +138,13 @@ void WorkspaceLayoutManager::SetChildBounds(aura::Window* child,
void WorkspaceLayoutManager::OnKeyboardBoundsChanging(
const gfx::Rect& new_bounds) {
- // If new window behavior flag enabled and in non-sticky mode, do not change
+ // If new window behavior is disable or the keyboard is in sticky mode, change
// the work area.

Powered by Google App Engine
This is Rietveld 408576698